@@ -1,7 +1,7 @@
 #*********************************************************************
 #*** ResourcePool::Factory::Net::LDAP
 #*** Copyright (c) 2002 by Markus Winand <mws@fatalmind.com>
-#*** $Id: LDAP.pm,v 1.12 2002/07/01 21:49:53 mws Exp $
+#*** $Id: LDAP.pm,v 1.14 2002/07/10 17:27:44 mws Exp $
 #*********************************************************************
 
 package ResourcePool::Factory::Net::LDAP;
@@ -12,7 +12,7 @@ use ResourcePool::Resource::Net::LDAP;
 use Data::Dumper;
 
 push @ISA, "ResourcePool::Factory";
-$VERSION = "0.9905";
+$VERSION = "0.9906";
 
 sub new($$@) {
         my ($proto) = shift;
@@ -129,7 +129,10 @@ $factory->create_resource() method wich is invoked from the ResourcePool.
 
 =head1 SEE ALSO
 
-Net::LDAP(3pm), ResourcePool(3pm), ResourcePool::Factory(3pm), ResourcePool::Factory::DBI(3pm)
+L<Net::LDAP(3pm)>, 
+L<ResourcePool(3pm)>, 
+L<ResourcePool::Factory(3pm)>, 
+L<ResourcePool::Factory::DBI(3pm)>
 
 =head1 AUTHOR
 
